[SC-1259] Change status of auto resolved alerts

From "Solved" to "Auto-solved" to help make reporting more clear about
how an alert was resolved.

Change-Id: If12e0080ea492aa204b364151edd8854c6fc3ec0
diff --git a/sensu/files/plugins/handlers/notification/sfdc.py b/sensu/files/plugins/handlers/notification/sfdc.py
index 9b0e48c..c6293d6 100755
--- a/sensu/files/plugins/handlers/notification/sfdc.py
+++ b/sensu/files/plugins/handlers/notification/sfdc.py
@@ -240,8 +240,8 @@
                 # Update Case
                 # If ok, mark case as solved.
                 if notification == "RECOVERY":
-                    data['Status'] = 'Solved'
-                    feed_data_body['Status'] = 'Solved'
+                    data['Status'] = 'Auto-solved'
+                    feed_data_body['Status'] = 'Auto-solved'
 
                 u = sfdc_client.update_case(id=ExistingCaseId, data=data)
                 LOG.debug('Upate status code: {} '.format(u.status_code))
@@ -269,9 +269,9 @@
             # overwritten on any update
             CaseId = new_case.json()['id']
 
             # If OK, ensure "Solved" is in the first feed.
             if notification == "RECOVERY":
-                feed_data_body['Status'] = 'Solved'
+                feed_data_body['Status'] = 'Auto-solved'
             feeditem_data = {
               'ParentId':   CaseId,
               'Visibility': 'AllUsers',
@@ -289,7 +289,7 @@
 
             # If OK, mark case as solved.
             if notification == "RECOVERY":
-                data['Status'] = 'Solved'
+                data['Status'] = 'Auto-solved'
 
             u = sfdc_client.update_case(id=CaseId, data=data)
             LOG.debug('Update status code: {} '.format(u.status_code))
@@ -269,9 +269,9 @@
             CaseId = new_case.json()['id']
 
-            # If OK, ensure "Solved" is in the first feed.
+            # If OK, ensure "Auto-solved" is in the first feed.
             if notification == "RECOVERY":